import {Component, OnDestroy, OnInit} from "@angular/core";
import {StakeholderService} from "../openaireLibrary/monitor/services/stakeholder.service";
import {Stakeholder} from "../openaireLibrary/monitor/entities/stakeholder";
import {Subscription} from "rxjs";
import {Meta, Title} from "@angular/platform-browser";
import {SEOService} from "../openaireLibrary/sharedComponents/SEO/SEO.service";
import {properties} from "../../environments/environment";
import {ActivatedRoute, Router} from "@angular/router";

@Component({
  selector: 'methodology',
  template: `
    <div page-content>
      <div inner>
        <div class="uk-container uk-container-large uk-section-small">
          <h2 class="uk-text-center">
            Terminology and construction
          </h2>
          <div class="uk-margin-large-top">
            <ul class="uk-tab admin customTabs uk-margin-medium-bottom" uk-tab>
              <li [class.uk-active]="tab === 'entities'"><a (click)="tab = 'entities'"><span
                  class="title">Entities</span></a></li>
              <li [class.uk-active]="tab === 'attributes'"><a (click)="tab = 'attributes'"><span class="title">Inherited and Inferred Attributes</span></a>
              </li>
							<li [class.uk-active]="tab === 'constructedAttributes'"><a (click)="tab = 'constructedAttributes'"><span class="title">Constructed Attributes</span></a></li>
            </ul>
            <ng-container *ngIf="tab === 'entities'">
							<table>
								<tr>
									<th class="important">Research Outcomes</th>
									<td>
										<div>There are currently four different types of research outcomes in the OpenAIRE Research
											Graph:
										</div>
										<ul class="portal-circle">
											<li>publications</li>
											<li>datasets</li>
											<li>software</li>
											<li>other research products.</li>
										</ul>
										<div class="uk-margin-small-top">
											OpenAIRE deduplicates (merges) different records of research outcomes and keeps the metadata of all
											instances.
										</div>
									</td>
								</tr>
								<tr>
									<th>Publication</th>
									<td>Research outcomes intended for human reading (published articles, pre-prints, conference papers,
										presentations, technical reports, etc.)
									</td>
								</tr>
								<tr>
									<th>Dataset</th>
									<td>
										<p>Research data</p>
										<p>Granularity is not defined by OpenAIRE, it reflects the granularity supported by
											the sources from which the description of the dataset has been collected.</p>
									</td>
								</tr>
								<tr>
									<th>Software</th>
									<td>Source code or software package developed and/or used in a research context</td>
								</tr>
								<tr>
									<th>Other Research Product</th>
									<td>Anything that does not fall in the previous categories (e.g. workflow, methods, protocols)</td>
								</tr>
							</table>
            </ng-container>
            <ng-container *ngIf="tab === 'attributes'">
							<div>
								<p class="uk-text-center uk-text-small">
									The attributes of entities listed below are either inherited via entries in the harvested metadata records
									or automatically generated by our inference (text and data mining) algorithms.
								</p>
							</div>
							<table>
								<tr>
									<th>Organization</th>
									<td>
										<p><span class="uk-text-bold">For research outcomes,</span> this refers to the affiliated organizations of its authors</p>
										<p><span class="uk-text-bold">For projects:</span> the organizations participating in the project
											(i.e. beneficiaries of the grant)
										</p>
										<p>The OpenAIRE research graph is in the process of improving the organization database (disambiguation) with the newly developed <a href="https://www.openaire.eu/blogs/openorgs-bridging-registries-of-research-organisations" target="_blank">OpenOrgs</a> tool.</p>
									</td>
								</tr>
								<tr>
									<th>Country</th>
									<td>
										<p>The country of the organization. </p>
										<p>
											<span class="uk-text-bold">Country code mapping: </span>
											<a href="https://api.openaire.eu/vocabularies/dnet:countries" target="_blank">
												https://api.openaire.eu/vocabularies/dnet:countries</a>
										</p>	
									</td>
								</tr>
								<tr>
									<th>Funder</th>
									<td>
										<p>Funders that have joined OpenAIRE, i.e. their project data have gone through a validation process.</p>
										<p>You can visit <a href="https://explore.openaire.eu/search/find" target="_blank">https://explore.openaire.eu/search/find</a> if you would like to explore the research outcomes and projects of all funders in OpenAIRE (the list of funders can be seen under the "Funder" Filter shown on the left side of the page).</p>
										<p><span class="uk-text-bold">To join: </span><a href="https://www.openaire.eu/funders-how-to-join-guide" target="_blank">https://www.openaire.eu/funders-how-to-join-guide</a></p>
									</td>
								</tr>
								<tr>
									<th>Type</th>
									<td>
										<p>The sub-type of a research outcome (e.g., a publication can be a pre-print, conference proceeding,
											article,
											etc.)</p>
										<p><span class="uk-text-bold">Resource type mapping: </span>
											<a href="https://api.openaire.eu/vocabularies/dnet:result_typologies" target="_blank">https://api.openaire.eu/vocabularies/dnet:result_typologies</a>
											(click on the code to see the specific types for each result type)
										</p>
									</td>
								</tr>
								<tr>
									<th>Access mode or access rights</th>
									<td>
										<p>The best available (across all instances) access rights of a research outcome</p>
										<p>Types: open, restricted, closed, embargo (= closed for a specific period of time, then open)</p>
										<p><span class="uk-text-bold">Note:</span> definition of <span class="uk-text-bold">restricted</span>
											may vary by data source, it may refer to access rights being given to registered users, potentially behind a paywall.</p>
									</td>
								</tr>
								<tr>
									<th>CC license</th>
									<td>
										<p>A Creative Commons copyright license <a href="(https://creativecommons.org/)" target="_blank">(https://creativecommons.org/)</a></p>
									</td>
								</tr>
								<tr>
									<th>PID (persistent identifier)</th>
									<td>
										<p>A long-lasting reference to a resource</p>
										<p><span class="uk-text-bold">Types: </span> <a
												href="http://api.openaire.eu/vocabularies/dnet:pid_types" target="_blank">http://api.openaire.eu/vocabularies/dnet:pid_types</a>
										</p>
									</td>
								</tr>
								<tr>
									<th>Context</th>
									<td>Related research community, initiative or infrastructure</td>
								</tr>
								<tr>
									<th>Journal</th>
									<td>The scientific journal an article is published in.</td>
								</tr>
								<tr>
									<th>Publisher</th>
									<td>The publisher of the venue (journal, book, etc.) of a research outcome</td>
								</tr>
								<tr>
									<th class="important">Data sources (content providers)</th>
									<td>
										<p>The different data sources ingested in the OpenAIRE Research Graph.</p>
										<div class="uk-text-bold">Data Source Types:</div>
										<ul class="portal-circle">
											<li>Repositories</li>
											<li>Open Access Publishers & Journals</li>
											<li>Aggregators</li>
											<li>Entity Registries</li>
											<li>Journal Aggregators</li>
											<li>CRIS (Current Research Information System)</li>
										</ul>
									</td>
								</tr>
								<tr>
									<th>Repositories</th>
									<td>Information systems where scientists upload the bibliographic metadata and payloads of their
										research outcomes (e.g. PDFs of their scientific articles, CSVs of their data, archive with their
										software), due to obligations from their organizations, their funders, or due to community practices
										(e.g. ArXiv, Europe PMC, Zenodo).
									</td>
								</tr>
								<tr>
									<th>Open Access Publishers & Journals</th>
									<td>Information systems of open access publishers or relative journals, which offer bibliographic
										metadata and PDFs of their published articles.
									</td>
								</tr>
								<tr>
									<th>Aggregators</th>
									<td>Information systems that collect descriptive metadata about research products from multiple sources
										in order to enable cross-data source discovery of given research products (e,g, DataCite,
										BASE, DOAJ).
									</td>
								</tr>
								<tr>
									<th>Entity Registries</th>
									<td>Information systems created with the intent of maintaining authoritative registries of given
										entities in the scholarly communication, such as OpenDOAR for the institutional repositories, re3data
										for the data repositories, CORDA and other funder databases for projects and funding information.
									</td>
								</tr>
								<tr>
									<th>CRIS (Current Research Information System)</th>
									<td>Information systems adopted by research and academic organizations to keep track of their research
										administration records and relative results; examples of CRIS content are articles or datasets funded
										by projects, their principal investigators, facilities acquired thanks to funding, etc.
									</td>
								</tr>
							</table>
            </ng-container>
						<ng-container *ngIf="tab === 'constructedAttributes'">
							<div>
								<p class="uk-text-center uk-text-small">The attributes of entities under this tab are constructed following the methodology described below.</p>
							</div>
							<table>
								<thead>
									<tr>
										<th>Attribute</th>
										<td class="uk-text-bold">Definition</td>
										<td class="uk-text-bold">Construction</td>
									</tr>
								</thead>
								<tbody>
									<tr>
										<th class="important" colspan="3">Journal Business Models</th>
									</tr>
									<tr>
										<th>
											<p>Fully Open Access (OA)</p>
										</th>
										<td>
											<p>A journal that publishes only in open access.</p>
										</td>
										<td>
											<p>We construct the list of fully OA journals using Unpaywall data. </p>
											<p>In brief, a journal is fully OA if </p>
											<ol>
												<li>It is in the Directory of Open Access Journals (DOAJ) </li>
												<li>It has a known (curated list) fully OA Publisher. </li>
												<li>It only publishes OA articles. </li>
											</ol>
											<p><a href="https://support.unpaywall.org/support/solutions/articles/44001792752-how-do-we-decide-if-a-given-journal-is-fully-oa-" target="_blank">More information</a></p>
										</td>
									</tr>
									<tr>
										<th>
											<p>Subscription</p>
										</th>
										<td>
											<p>A journal that charges for access to its articles.</p>
										</td>
										<td>
											<p>Journals without any open access articles.</p>
										</td>
									</tr>
									<tr>
										<th>
											<p>Hybrid</p>
										</th>
										<td>
											<p>A subscription journal where some of its articles are open access.</p>
										</td>
										<td>
											<p>Journals with open access articles that are not fully OA journals are hybrid.</p>
										</td>
									</tr>
									<tr>
										<th>
											<p>Transformative</p>
										</th>
										<td>
											<p>"A Transformative Journal is a subscription/hybrid journal that is actively committed to transitioning to a fully Open Access journal.</p>
											<p>In addition, a Transformative Journal must:</p>
											<ul>
												<li>gradually increase the share of Open Access content; and</li>
												<li>offset subscription income from payments for publishing services (to avoid double payments)."</li>
											</ul>
											<p>Source:</p>
											<p><a href="https://www.coalition-s.org/transformative-journals-faq/" target="_blank">https://www.coalition-s.org/transformative-journals-faq/</a></p>
										</td>
										<td>
											<p>Transformative Journals are identified by ISSN matching with the publicly available Transformative Journals data (<a href="https://journalcheckertool.org/transformative-journals/" target="_blank">https://journalcheckertool.org/transformative-journals/</a>)</p>
											<p></p>
										</td>
									</tr>
									<tr>
										<th class="important" colspan="3">Journal APC Business Models</th>
									</tr>
									<tr>
										<th>Diamond OA</th>
										<td>
											<p>
												A fully OA journal that does not charge article processing charges (APCs).
											</p>
										</td>
										<td>
											<p>
												APC information is obtained from DOAJ using DOAJ’s exportable version of the journal metadata (<a href="https://doaj.org/docs/public-data-dump/" target="_blank">https://doaj.org/docs/public-data-dump/</a>). We used it to determine whether a particular fully OA journal charges APCs. 
											</p>
										</td>
									</tr>
									<tr>
										<th class="important" colspan="3">Routes to Open Access (OA)</th>
									</tr>
									<tr>
										<th>Green OA</th>
										<td>
											<p>
												An open access scientific publication deposited in a repository
											</p>
										</td>
										<td>
											<p>
												As in definition
											</p>
										</td>
									</tr>
									<tr>
										<th>Gold OA</th>
										<td>
											<p>
												A scientific publication published in a fully OA journal.
											</p>
										</td>
										<td>
											<p>
												Fully OA journals are defined above.
											</p>
										</td>
									</tr>
									<!-- next two row have the same 3rd cell -->
									<tr>
										<th>Hybrid OA</th>
										<td>
											<p>
												An open access scientific publication published in a hybrid journal with an open license.
											</p>
										</td>
										<td rowspan="2">
											<p>Hybrid journals are defined above.</p>
											<p>At this point we consider only CC licenses “open”, we are currently working on cleaning non-CC licenses as well to identify other open ones.</p>
											<p>In principle, this means that we may be underestimating the number of hybrid OA articles and overestimating the number of bronze.</p>
										</td>
									</tr>
									<tr>
										<th>Bronze OA</th>
										<td>
											<p>
												An open access scientific publication published in a hybrid journal without an open license.
											</p>
										</td>
									</tr>
									<tr>
										<th class="important" colspan="3">Miscellaneous</th>
									</tr>
									<tr>
										<th>Downloads</th>
										<td>
											<p>
												The number of downloads of a publication’s full text in a specific time frame, from a given set of data sources.
											</p>
										</td>
										<td>
											<p>
												Data for downloads is taken from OpenAIRE’s Usage Counts service that harvests it from a set of repositories. The time range of available downloads varies for each repository.
											</p>
											<p>
												<a href="https://www.openaire.eu/guides-usage-counts" target="_blank">More information</a>
											</p>
										</td>
									</tr>
								</tbody>
							</table>
						</ng-container>
            <div class="uk-text-small uk-margin-small-top">
              <img src="assets/common-assets/graph.svg" style="opacity: 0.4">
              <span class="uk-margin-small-left uk-text-baseline uk-text-muted">More information for <a
                  href="https://graph.openaire.eu" class="graph-color">OpenAIRE Research Graph</a>.</span>
            </div>
          </div>
        </div>
        <div id="how" class="uk-container uk-container-large uk-section-small">
          <h2 class="uk-text-center">
            See how it works
          </h2>
					<div class="uk-margin-large-top uk-card uk-card-default uk-card-body">
						<p class="uk-margin-top">Our methodological approach is based on the following operational quality criteria:</p>
						<ul>
							<li><span class="uk-text-bold">Openness and transparency:</span> Methodological assumptions are openly and clearly presented.</li>
							<li><span class="uk-text-bold">Coverage and accuracy:</span> As detailed in <a href="https://graph.openaire.eu/" target="_blank">graph.openaire.eu</a>
								multiple data sources are ingested in the OpenAIRE research graph for coverage to the fullest extent possible, in order to provide meaningful indicators.</li>
							<li><span class="uk-text-bold">Clarity and replicability:</span> We describe our construction methodology in detail, so that
								it can be verified and used by the scholarly communication community to create ongoing updates to our proposed statistics and indicators.</li>
							<li><span class="uk-text-bold">Readiness and timeliness:</span> The methodology is built around well-established open databases
								and already tested knowledge extraction technologies - natural language processing (NLP)/machine-learning (ML) - using operational
								workflows in OpenAIRE to warrant timely results.</li>
							<li><span class="uk-text-bold">Trust and robustness:</span> Our methodology also strives to be reliable, robust, and aligned
								to other assessment methods so that it can be operationalized, used and reused, in conjunction with other assessment methods.</li>
						</ul>
						<div class="uk-text-small uk-text-italic uk-text-right">The text above is modified from <a href="https://op.europa.eu/en/publication-detail/-/publication/56cc104f-0ebb-11ec-b771-01aa75ed71a1"
							target="_blank">this report</a> (DOI: 10.2777/268348).</div>
					</div>
          <div class="uk-margin-large-top">
						<h3 class="uk-h4">Step-by-step</h3>
            <how></how>
          </div>
        </div>
      </div>
    </div>
  `,
  styleUrls: ['methodology.component.css']
})
export class MethodologyComponent implements OnInit, OnDestroy {
  public stakeholder: Stakeholder;
  public tab: 'entities' | 'attributes' | 'constructedAttributes'= 'entities';
  private subscriptions: any[] = [];
  
  constructor(private stakeholderService: StakeholderService,
              private seoService: SEOService,
              private _meta: Meta,
              private _router: Router,
              private route: ActivatedRoute,
              private _title: Title) {
  }
  
  ngOnInit() {
    this.subscriptions.push(this.stakeholderService.getStakeholderAsObservable().subscribe(stakeholder => {
      this.stakeholder = stakeholder;
      if (this.stakeholder) {
        /* Metadata */
        const url = properties.domain + properties.baseLink + this._router.url;
        this.seoService.createLinkForCanonicalURL(url, false);
        this._meta.updateTag({content: url}, "property='og:url'");
        const description = "Methodology | " + this.stakeholder.name;
        const title = "Methodology | " + this.stakeholder.name;
        this._meta.updateTag({content: description}, "name='description'");
        this._meta.updateTag({content: description}, "property='og:description'");
        this._meta.updateTag({content: title}, "property='og:title'");
        this._title.setTitle(title);
      }
    }));
  }
  
  ngOnDestroy() {
    this.subscriptions.forEach(subscription => {
      if (subscription instanceof Subscription) {
        subscription.unsubscribe();
      }
    });
  }
}
